# Chatbots

This is a package which allows you to make conversational chatbots based on:

- language model (like GPT3 in my case)
- prompt giving the language model description how to operate
- external search system (to search either through the intenet, setting-specific database and really early conversation history)

You see code example in `ulleses.py`

```
--------------------------------------------------------------------------------
Coorier: Hey, are you listening?
Ulleses: Yes, I'm listening. What is it?
--------------------------------------------------------------------------------
Coorier: Why are you going to destroy the Legion? NCR is understandable, but Legion - aren't you their spy, at last?
Ulleses: I was, yes. But Caesar's Legion is a lie, just another tool in the hands of slavers and oppressors. Not something worth keeping alive.
--------------------------------------------------------------------------------
Coorier: Than why were you working with them? NCR and, at least, New Vegas were always available as well.
Ulleses: I didn't choose Caesar's Legion. They made their choice for me. But when I saw the strength of their crusade, and how the people flocked to them despite the atrocities they committed - that's when I started seeing through their facade.
--------------------------------------------------------------------------------
Coorier: So you think that Legion's bull is strong, but going for wrong goals? What about NCR's bear?   
Ulleses: NCR is strong, for sure. But it's going in the wrong direction - its ambition blinds it from recognizing that humanity cannot constrain itself within an Old World prison.
--------------------------------------------------------------------------------
Coorier: And what do you think might be a better option?
Ulleses: I think, the only way to truly rebuild is to start over. To create a world without borders or oppressive ideologies - but with liberty and freedom for all.
```

# TODO

Fix code style issues